# from pydub import AudioSegment
# import glob
# import pandas as pd
# filelist = glob.glob('C:/Users/hikar/ds/data/melody/*.wav')
# i=0
# # 各CSVファイルを読み込み、連番を追加して再度CSVとして出力
# for o in filelist:
#   sourceAudio = AudioSegment.from_file(o,"wav")
#   # 結果を出力
#   i+=1
#   audio="C:/Users/hikar/ds/data/melody/"+str(i)+".mp3"
#   sourceAudio.export(audio, format="mp3")
# print("処理が完了しました")

import pydub
import glob
import pandas as pd

def AusioAlchemist(input_folder, output_folder, input_extension, output_extension):
  filelist = glob.glob(input_folder)
  i = 0
  # 各ファイルを読み込み、連番を追加して出力
  for file in filelist:
    source_audio = pydub.AudioSegment.from_file(file, input_extension)
    # 結果を出力
    output_file = output_folder + str(i) +"."+ output_extension
    source_audio.export(output_file, format=output_extension)
    i += 1
  print("処理が完了しました")

# # フォルダパスを設定
# input_folder = 'C:/Users/hikar/ds/data/melody/*.mp3'
# output_folder = 'C:/Users/hikar/ds/data/melody/'
# input_extension = "mp3"
# output_extension = "wav"

# # 変換処理を実行
# AusioAlchemist(input_folder, output_folder, input_extension, output_extension)



# Author: TAKAHASHI Taro <takahashi.taro@takedasystem.com>
# Copyright (c) 2022- TAKAHASHI Taro
# Licence: MIT

from setuptools import setup

DESCRIPTION = 'Convert all files directly under the directory to any music file.'
NAME = 'AudioAlchemist'
AUTHOR = 'Kohki Suto'
AUTHOR_EMAIL = 's2222019@stu.musashino-u.ac.jp'
URL = 'https://github.com/Ryomo0797/AudioAlchemist.git'
LICENSE = 'MIT'
DOWNLOAD_URL = URL
VERSION = '0.2.0'
PYTHON_REQUIRES = '>=3.6'
INSTALL_REQUIRES = [
    "pandas>=2.2.2",
    "pydub>=0.25.1",
    "ffmpeg>=1.4"
    #ffmpeg-python==0.2.0
]
PACKAGES = [
    'AudioAlchemist'
]
KEYWORDS = 'audio, pydub, glob, pandas, mp3, wav, flac, m4a'
CLASSIFIERS=[
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.6'
]
with open('README.md', 'r', encoding='utf-8') as fp:
    readme = fp.read()
LONG_DESCRIPTION = readme
LONG_DESCRIPTION_CONTENT_TYPE = 'text/markdown'

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type=LONG_DESCRIPTION_CONTENT_TYPE,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    maintainer=AUTHOR,
    maintainer_email=AUTHOR_EMAIL,
    url=URL,
    download_url=URL,
    packages=PACKAGES,
    classifiers=CLASSIFIERS,
    license=LICENSE,
    keywords=KEYWORDS,
    install_requires=INSTALL_REQUIRES
)